@@ -39,6 +39,9 @@ class SendGrid(object):
                 "add": "/api/newsletter/identity/add.json",
                 "list": "/api/newsletter/identity/list.json",
                 "get": "/api/newsletter/identity/get.json"},
+            "subuser":{ #create new subuser
+                "add": "/apiv2/customer.add.json",
+                "list": "/apiv2/customer.profile.json"}
         }
 
     def build_params(self, d=None):
@@ -153,6 +156,12 @@ class SendGrid(object):
             d = dict(name=newsletter_name)
         return self.call('schedule', 'add', d)
 
+    def add_subuser(self, **fields):
+        return self.call('subuser', 'add', dict(**fields))
+
+    def list_subusers(self):
+        return self.call('subuser', 'list', dict(task="get"))
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
